==> knative-model-5.3.1-sources.jar: annotations/io/fabric8/knative/eventing/contrib/kafka/v1beta1/KafkaSASLSpecFluentImpl.java <==
package io.fabric8.knative.eventing.contrib.kafka.v1beta1;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class KafkaSASLSpecFluentImpl<A extends KafkaSASLSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements KafkaSASLSpecFluent<A> {

    private Boolean enable;
    private io.fabric8.knative.eventing.contrib.kafka.v1beta1.SecretValueFromSourceBuilder password;
    private io.fabric8.knative.eventing.contrib.kafka.v1beta1.SecretValueFromSourceBuilder user;

    public KafkaSASLSpecFluentImpl() {
    }

    public KafkaSASLSpecFluentImpl(KafkaSASLSpec instance) {
        this.withEnable(instance.getEnable()); 
        this.withPassword(instance.getPassword()); 
        this.withUser(instance.getUser()); 
    }

    public Boolean getEnable() {
        return this.enable;
    }

    public A withEnable(Boolean enable) {
        this.enable=enable; return (A) this;
    }

    public Boolean hasEnable() {
        return this.enable != null;
    }

    public A withNewEnable(String arg1) {
        return (A)withEnable(new Boolean(arg1));
    }

    public A withNewEnable(boolean arg1) {
        return (A)withEnable(new Boolean(arg1));
    }

    
/**
 * This method has been deprecated, please use method buildPassword instead.
 * @return The buildable object.
 */
@Deprecated public io.fabric8.knative.eventing.contrib.kafka.v1beta1.SecretValueFromSource getPassword() {
        return this.password!=null?this.password.build():null;
    }

    public io.fabric8.knative.eventing.contrib.kafka.v1beta1.SecretValueFromSource buildPassword() {
        return this.password!=null?this.password.build():null;
    }

    public A withPassword(io.fabric8.knative.eventing.contrib.kafka.v1beta1.SecretValueFromSource password) {
        _visitables.get("password").remove(this.password);
        if (password!=null){ this.password= new io.fabric8.knative.eventing.contrib.kafka.v1beta1.SecretValueFromSourceBuilder(password); _visitables.get("password").add(this.password);} return (A) this;
    }

    public Boolean hasPassword() {
        return this.password != null;
    }

    public io.fabric8.knative.eventing.contrib.kafka.v1beta1.KafkaSASLSpecFluent.PasswordNested<A> withNewPassword() {
        return new PasswordNestedImpl();
    }

    public io.fabric8.knative.eventing.contrib.kafka.v1beta1.KafkaSASLSpecFluent.PasswordNested<A> withNewPasswordLike(io.fabric8.knative.eventing.contrib.kafka.v1beta1.SecretValueFromSource item) {
        return new PasswordNestedImpl(item);
    }

    public io.fabric8.knative.eventing.contrib.kafka.v1beta1.KafkaSASLSpecFluent.PasswordNested<A> editPassword() {
        return withNewPasswordLike(getPassword());
    }

    public io.fabric8.knative.eventing.contrib.kafka.v1beta1.KafkaSASLSpecFluent.PasswordNested<A> editOrNewPassword() {
        return withNewPasswordLike(getPassword() != null ? getPassword(): new io.fabric8.knative.eventing.contrib.kafka.v1beta1.SecretValueFromSourceBuilder().build());
    }

    public io.fabric8.knative.eventing.contrib.kafka.v1beta1.KafkaSASLSpecFluent.PasswordNested<A> editOrNewPasswordLike(io.fabric8.knative.eventing.contrib.kafka.v1beta1.SecretValueFromSource item) {
        return withNewPasswordLike(getPassword() != null ? getPassword(): item);
    }

    
/**
 * This method has been deprecated, please use method buildUser instead.
 * @return The buildable object.
 */
@Deprecated public io.fabric8.knative.eventing.contrib.kafka.v1beta1.SecretValueFromSource getUser() {
        return this.user!=null?this.user.build():null;
    }

    public io.fabric8.knative.eventing.contrib.kafka.v1beta1.SecretValueFromSource buildUser() {
        return this.user!=null?this.user.build():null;
    }

    public A withUser(io.fabric8.knative.eventing.contrib.kafka.v1beta1.SecretValueFromSource user) {
        _visitables.get("user").remove(this.user);
        if (user!=null){ this.user= new io.fabric8.knative.eventing.contrib.kafka.v1beta1.SecretValueFromSourceBuilder(user); _visitables.get("user").add(this.user);} return (A) this;
    }

    public Boolean hasUser() {
        return this.user != null;
    }

    public io.fabric8.knative.eventing.contrib.kafka.v1beta1.KafkaSASLSpecFluent.UserNested<A> withNewUser() {
        return new UserNestedImpl();
    }

    public io.fabric8.knative.eventing.contrib.kafka.v1beta1.KafkaSASLSpecFluent.UserNested<A> withNewUserLike(io.fabric8.knative.eventing.contrib.kafka.v1beta1.SecretValueFromSource item) {
        return new UserNestedImpl(item);
    }

    public io.fabric8.knative.eventing.contrib.kafka.v1beta1.KafkaSASLSpecFluent.UserNested<A> editUser() {
        return withNewUserLike(getUser());
    }

    public io.fabric8.knative.eventing.contrib.kafka.v1beta1.KafkaSASLSpecFluent.UserNested<A> editOrNewUser() {
        return withNewUserLike(getUser() != null ? getUser(): new io.fabric8.knative.eventing.contrib.kafka.v1beta1.SecretValueFromSourceBuilder().build());
    }

    public io.fabric8.knative.eventing.contrib.kafka.v1beta1.KafkaSASLSpecFluent.UserNested<A> editOrNewUserLike(io.fabric8.knative.eventing.contrib.kafka.v1beta1.SecretValueFromSource item) {
        return withNewUserLike(getUser() != null ? getUser(): item);
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        KafkaSASLSpecFluentImpl that = (KafkaSASLSpecFluentImpl) o;
        if (enable != null ? !enable.equals(that.enable) :that.enable != null) return false;
        if (password != null ? !password.equals(that.password) :that.password != null) return false;
        if (user != null ? !user.equals(that.user) :that.user != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(enable,  password,  user,  super.hashCode());
    }

    public class PasswordNestedImpl<N> extends io.fabric8.knative.eventing.contrib.kafka.v1beta1.SecretValueFromSourceFluentImpl<io.fabric8.knative.eventing.contrib.kafka.v1beta1.KafkaSASLSpecFluent.PasswordNested<N>> implements io.fabric8.knative.eventing.contrib.kafka.v1beta1.KafkaSASLSpecFluent.PasswordNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final io.fabric8.knative.eventing.contrib.kafka.v1beta1.SecretValueFromSourceBuilder builder;

            PasswordNestedImpl(io.fabric8.knative.eventing.contrib.kafka.v1beta1.SecretValueFromSource item) {
                this.builder = new io.fabric8.knative.eventing.contrib.kafka.v1beta1.SecretValueFromSourceBuilder(this, item);
                        
            }

            PasswordNestedImpl() {
                this.builder = new io.fabric8.knative.eventing.contrib.kafka.v1beta1.SecretValueFromSourceBuilder(this);
                        
            }

            public N and() {
                return (N) KafkaSASLSpecFluentImpl.this.withPassword(builder.build());
            }

            public N endPassword() {
                return and();
            }
    }


    public class UserNestedImpl<N> extends io.fabric8.knative.eventing.contrib.kafka.v1beta1.SecretValueFromSourceFluentImpl<io.fabric8.knative.eventing.contrib.kafka.v1beta1.KafkaSASLSpecFluent.UserNested<N>> implements io.fabric8.knative.eventing.contrib.kafka.v1beta1.KafkaSASLSpecFluent.UserNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final io.fabric8.knative.eventing.contrib.kafka.v1beta1.SecretValueFromSourceBuilder builder;

            UserNestedImpl(io.fabric8.knative.eventing.contrib.kafka.v1beta1.SecretValueFromSource item) {
                this.builder = new io.fabric8.knative.eventing.contrib.kafka.v1beta1.SecretValueFromSourceBuilder(this, item);
                        
            }

            UserNestedImpl() {
                this.builder = new io.fabric8.knative.eventing.contrib.kafka.v1beta1.SecretValueFromSourceBuilder(this);
                        
            }

            public N and() {
                return (N) KafkaSASLSpecFluentImpl.this.withUser(builder.build());
            }

            public N endUser() {
                return and();
            }
    }


}

==> knative-model-5.7.2-sources.jar: annotations/io/fabric8/knative/eventing/contrib/kafka/v1beta1/KafkaSASLSpecFluentImpl.java <==
package io.fabric8.knative.eventing.contrib.kafka.v1beta1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class KafkaSASLSpecFluentImpl<A extends io.fabric8.knative.eventing.contrib.kafka.v1beta1.KafkaSASLSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.knative.eventing.contrib.kafka.v1beta1.KafkaSASLSpecFluent<A> {

    private java.lang.Boolean enable;
    private io.fabric8.knative.eventing.contrib.kafka.v1beta1.SecretValueFromSourceBuilder password;
    private io.fabric8.knative.eventing.contrib.kafka.v1beta1.SecretValueFromSourceBuilder user;

    public KafkaSASLSpecFluentImpl() {
    }

    public KafkaSASLSpecFluentImpl(io.fabric8.knative.eventing.contrib.kafka.v1beta1.KafkaSASLSpec instance) {
        this.withEnable(instance.getEnable()); 
        this.withPassword(instance.getPassword()); 
        this.withUser(instance.getUser()); 
    }

    public java.lang.Boolean getEnable() {
        return this.enable;
    }

    public A withEnable(java.lang.Boolean enable) {
        this.enable=enable; return (A) this;
    }

    public java.lang.Boolean hasEnable() {
        return this.enable != null;
    }

    
    @java.lang.Deprecated
        
    /**
     * This method has been deprecated, please use method buildPassword instead.
     * @return The buildable object.
     */
        public io.fabric8.knative.eventing.contrib.kafka.v1beta1.SecretValueFromSource getPassword() {
        return this.password!=null?this.password.build():null;
    }

    public io.fabric8.knative.eventing.contrib.kafka.v1beta1.SecretValueFromSource buildPassword() {
        return this.password!=null?this.password.build():null;
    }

    public A withPassword(io.fabric8.knative.eventing.contrib.kafka.v1beta1.SecretValueFromSource password) {
        _visitables.get("password").remove(this.password);
        if (password!=null){ this.password= new io.fabric8.knative.eventing.contrib.kafka.v1beta1.SecretValueFromSourceBuilder(password); _visitables.get("password").add(this.password);} return (A) this;
    }

    public java.lang.Boolean hasPassword() {
        return this.password != null;
    }

    public io.fabric8.knative.eventing.contrib.kafka.v1beta1.KafkaSASLSpecFluent.PasswordNested<A> withNewPassword() {
        return new io.fabric8.knative.eventing.contrib.kafka.v1beta1.KafkaSASLSpecFluentImpl.PasswordNestedImpl();
    }

    public io.fabric8.knative.eventing.contrib.kafka.v1beta1.KafkaSASLSpecFluent.PasswordNested<A> withNewPasswordLike(io.fabric8.knative.eventing.contrib.kafka.v1beta1.SecretValueFromSource item) {
        return new io.fabric8.knative.eventing.contrib.kafka.v1beta1.KafkaSASLSpecFluentImpl.PasswordNestedImpl(item);
    }

    public io.fabric8.knative.eventing.contrib.kafka.v1beta1.KafkaSASLSpecFluent.PasswordNested<A> editPassword() {
        return withNewPasswordLike(getPassword());
    }

    public io.fabric8.knative.eventing.contrib.kafka.v1beta1.KafkaSASLSpecFluent.PasswordNested<A> editOrNewPassword() {
        return withNewPasswordLike(getPassword() != null ? getPassword(): new io.fabric8.knative.eventing.contrib.kafka.v1beta1.SecretValueFromSourceBuilder().build());
    }

    public io.fabric8.knative.eventing.contrib.kafka.v1beta1.KafkaSASLSpecFluent.PasswordNested<A> editOrNewPasswordLike(io.fabric8.knative.eventing.contrib.kafka.v1beta1.SecretValueFromSource item) {
        return withNewPasswordLike(getPassword() != null ? getPassword(): item);
    }

    
    @java.lang.Deprecated
        
    /**
     * This method has been deprecated, please use method buildUser instead.
     * @return The buildable object.
     */
        public io.fabric8.knative.eventing.contrib.kafka.v1beta1.SecretValueFromSource getUser() {
        return this.user!=null?this.user.build():null;
    }

    public io.fabric8.knative.eventing.contrib.kafka.v1beta1.SecretValueFromSource buildUser() {
        return this.user!=null?this.user.build():null;
    }

    public A withUser(io.fabric8.knative.eventing.contrib.kafka.v1beta1.SecretValueFromSource user) {
        _visitables.get("user").remove(this.user);
        if (user!=null){ this.user= new io.fabric8.knative.eventing.contrib.kafka.v1beta1.SecretValueFromSourceBuilder(user); _visitables.get("user").add(this.user);} return (A) this;
    }

    public java.lang.Boolean hasUser() {
        return this.user != null;
    }

    public io.fabric8.knative.eventing.contrib.kafka.v1beta1.KafkaSASLSpecFluent.UserNested<A> withNewUser() {
        return new io.fabric8.knative.eventing.contrib.kafka.v1beta1.KafkaSASLSpecFluentImpl.UserNestedImpl();
    }

    public io.fabric8.knative.eventing.contrib.kafka.v1beta1.KafkaSASLSpecFluent.UserNested<A> withNewUserLike(io.fabric8.knative.eventing.contrib.kafka.v1beta1.SecretValueFromSource item) {
        return new io.fabric8.knative.eventing.contrib.kafka.v1beta1.KafkaSASLSpecFluentImpl.UserNestedImpl(item);
    }

    public io.fabric8.knative.eventing.contrib.kafka.v1beta1.KafkaSASLSpecFluent.UserNested<A> editUser() {
        return withNewUserLike(getUser());
    }

    public io.fabric8.knative.eventing.contrib.kafka.v1beta1.KafkaSASLSpecFluent.UserNested<A> editOrNewUser() {
        return withNewUserLike(getUser() != null ? getUser(): new io.fabric8.knative.eventing.contrib.kafka.v1beta1.SecretValueFromSourceBuilder().build());
    }

    public io.fabric8.knative.eventing.contrib.kafka.v1beta1.KafkaSASLSpecFluent.UserNested<A> editOrNewUserLike(io.fabric8.knative.eventing.contrib.kafka.v1beta1.SecretValueFromSource item) {
        return withNewUserLike(getUser() != null ? getUser(): item);
    }

    public boolean equals(java.lang.Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        KafkaSASLSpecFluentImpl that = (KafkaSASLSpecFluentImpl) o;
        if (enable != null ? !enable.equals(that.enable) :that.enable != null) return false;
        if (password != null ? !password.equals(that.password) :that.password != null) return false;
        if (user != null ? !user.equals(that.user) :that.user != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(enable,  password,  user,  super.hashCode());
    }

    public class PasswordNestedImpl<N> extends io.fabric8.knative.eventing.contrib.kafka.v1beta1.SecretValueFromSourceFluentImpl<io.fabric8.knative.eventing.contrib.kafka.v1beta1.KafkaSASLSpecFluent.PasswordNested<N>> implements io.fabric8.knative.eventing.contrib.kafka.v1beta1.KafkaSASLSpecFluent.PasswordNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final io.fabric8.knative.eventing.contrib.kafka.v1beta1.SecretValueFromSourceBuilder builder;

            PasswordNestedImpl(io.fabric8.knative.eventing.contrib.kafka.v1beta1.SecretValueFromSource item) {
                this.builder = new io.fabric8.knative.eventing.contrib.kafka.v1beta1.SecretValueFromSourceBuilder(this, item);
                        
            }

            PasswordNestedImpl() {
                this.builder = new io.fabric8.knative.eventing.contrib.kafka.v1beta1.SecretValueFromSourceBuilder(this);
                        
            }

            public N and() {
                return (N) KafkaSASLSpecFluentImpl.this.withPassword(builder.build());
            }

            public N endPassword() {
                return and();
            }
    }


    public class UserNestedImpl<N> extends io.fabric8.knative.eventing.contrib.kafka.v1beta1.SecretValueFromSourceFluentImpl<io.fabric8.knative.eventing.contrib.kafka.v1beta1.KafkaSASLSpecFluent.UserNested<N>> implements io.fabric8.knative.eventing.contrib.kafka.v1beta1.KafkaSASLSpecFluent.UserNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final io.fabric8.knative.eventing.contrib.kafka.v1beta1.SecretValueFromSourceBuilder builder;

            UserNestedImpl(io.fabric8.knative.eventing.contrib.kafka.v1beta1.SecretValueFromSource item) {
                this.builder = new io.fabric8.knative.eventing.contrib.kafka.v1beta1.SecretValueFromSourceBuilder(this, item);
                        
            }

            UserNestedImpl() {
                this.builder = new io.fabric8.knative.eventing.contrib.kafka.v1beta1.SecretValueFromSourceBuilder(this);
                        
            }

            public N and() {
                return (N) KafkaSASLSpecFluentImpl.this.withUser(builder.build());
            }

            public N endUser() {
                return and();
            }
    }


}
